@@ -108,7 +108,7 @@ class InfimaClient:
     def demo(self) -> None:
         demo(self)
 
-    def get_as_of_predictions(
+    def get_predictions(
         self,
         symbols: List[str],
         as_of: Optional[DateT] = None,
@@ -155,7 +155,7 @@ class InfimaClient:
             raise ValueError("must specify only one of as_of or num_months")
 
         if as_of is not None:
-            return self.get_as_of_predictions(symbols=symbols, as_of=as_of, **kwargs)
+            return self.get_predictions(symbols=symbols, as_of=as_of, **kwargs)
         else:
             return self.get_n_months_ahead_predictions(
                 symbols=symbols, num_months=num_months, **kwargs
